Welcome to MTAP's documentation!
===================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   mtap
   deployment
   io

Overview
========

MTAP is a distributed computing framework for text analysis built on top of the gRPC framework.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
